@@ -1,7 +1,7 @@
 package App::wordlist;
 
-our $DATE = '2017-11-07'; # DATE
-our $VERSION = '0.260'; # VERSION
+our $DATE = '2017-11-08'; # DATE
+our $VERSION = '0.261'; # VERSION
 
 use 5.010001;
 use strict;
@@ -11,6 +11,25 @@ use List::Util qw(shuffle);
 
 our %SPEC;
 
+our %arg_wordlists = (
+    wordlists => {
+        'x.name.is_plural' => 1,
+        schema => ['array*' => of => 'str*'],
+        summary => 'Select one or more wordlist modules',
+        cmdline_aliases => {w=>{}},
+        element_completion => sub {
+            require Complete::Util;
+
+            my %args = @_;
+            Complete::Util::complete_array_elem(
+                word  => $args{word},
+                array => [map {$_->{name}} @{ _list_installed() }],
+                ci    => 1,
+            );
+        },
+    },
+);
+
 sub _list_installed {
     require Module::List;
     my $mods = Module::List::list_modules(
@@ -90,22 +109,7 @@ $SPEC{wordlist} = {
             schema  => 'bool*',
             cmdline_aliases => {r=>{}},
         },
-        wordlists => {
-            'x.name.is_plural' => 1,
-            schema => ['array*' => of => 'str*'],
-            summary => 'Select one or more wordlist modules',
-            cmdline_aliases => {w=>{}},
-            element_completion => sub {
-                require Complete::Util;
-
-                my %args = @_;
-                Complete::Util::complete_array_elem(
-                    word  => $args{word},
-                    array => [map {$_->{name}} @{ _list_installed() }],
-                    ci    => 1,
-                );
-            },
-        },
+        %arg_wordlists,
         or => {
             summary => 'Match any word in query instead of the default "all"',
             schema  => 'bool',
@@ -434,7 +438,7 @@ App::wordlist - Grep words from WordList::*
 
 =head1 VERSION
 
-This document describes version 0.260 of App::wordlist (from Perl distribution App-wordlist), released on 2017-11-07.
+This document describes version 0.261 of App::wordlist (from Perl distribution App-wordlist), released on 2017-11-08.
 
 =head1 SYNOPSIS
 
